@@ -71,7 +71,7 @@ class Metric:
     friendly_name: Optional[str] = None
     description: Optional[str] = None
     bigger_is_better: bool = True
-    analysis_bases: List[AnalysisBasis] = [AnalysisBasis.ENROLLMENTS]
+    analysis_bases: List[AnalysisBasis] = [AnalysisBasis.ENROLLMENTS, AnalysisBasis.EXPOSURES]
     type: str = "scalar"
     category: Optional[str] = None
 
@@ -174,7 +174,10 @@ class MetricDefinition:
                     f"No default definition found for referenced metric {self.name}"
                 )
 
-            metric_definition.analysis_bases = self.analysis_bases or [AnalysisBasis.ENROLLMENTS]
+            metric_definition.analysis_bases = self.analysis_bases or [
+                AnalysisBasis.ENROLLMENTS,
+                AnalysisBasis.EXPOSURES,
+            ]
             metric_definition.statistics = self.statistics
             metric_summary = metric_definition.resolve(spec, conf, configs)
         else:
@@ -193,7 +196,8 @@ class MetricDefinition:
                 else self.friendly_name,
                 description=dedent(self.description) if self.description else self.description,
                 bigger_is_better=self.bigger_is_better,
-                analysis_bases=self.analysis_bases or [AnalysisBasis.ENROLLMENTS],
+                analysis_bases=self.analysis_bases
+                or [AnalysisBasis.ENROLLMENTS, AnalysisBasis.EXPOSURES],
                 type=self.type or "scalar",
                 category=self.category,
             )
